@@ -1,4 +1,5 @@
-from sys import argv
+from sys import path, argv
+from os import getcwd
 
 from . import commands
 from .repl import repl
@@ -7,6 +8,8 @@ from .usage import usage
 
 
 def main():
+    path.insert(0, getcwd())
+
     if len(argv)>1:
         name = argv[1]
         if name in ('usage', 'help', '?'): return usage()
