@@ -9,7 +9,7 @@ def safe(cmd, target):
         try:
             cmd(target, arg)
         except Exception as x:
-            print(' !', x)
+            print(x)
     return do_cmd
 
 
